Structs
- BoxClamp
- Boundary constraints for size-based layout.
- Color
- Lightness
Tone - Describe the light tone of a color, should between [0, 1.0], 0.0 gives absolute black and 1.0 give the brightest white.
- Logic
Unit - The tag for logic unit system to prevent mixing values from different system.
- Physic
Unit - The tag for device unit system to prevent mixing values from different system.
Constants
Traits
Functions
- rect
- Shorthand for
Rect::new(Point2D::new(x, y), Size2D::new(w, h)). - rect_
corners - Return the four corners of a rectangle: [left-top, right-top, right-bottom, left-bottom]
- transform_
to_ device_ rect - Apply the transform to the rect and return the new rect as device unit.