pub type DeviceSize<T = i32> = Size2D<T, PhysicUnit>;Aliased Type
pub struct DeviceSize<T = i32> {
pub width: T,
pub height: T,
}Fields
width: TThe extent of the element in the U units along the x axis (usually horizontal).
height: TThe extent of the element in the U units along the y axis (usually vertical).